import { Component, OnInit, AfterViewInit, ViewChild } from '@angular/core';
import { MatTableDataSource, MatSort } from '@angular/material';
import { AfterContentInit } from '@angular/core/src/metadata/lifecycle_hooks';
import { Router } from '@angular/router';
import { Probe } from '../../model';
import { Store, select } from '@ngrx/store';
import * as ListStore from '../../store/list';
import { Domain } from '../../../domain/model';
import { AuthSelector } from '../../../member/store';
import { ErrorResponse } from '../../../commons/service/error-response';
import { ListSelector } from '../../store';

@Component({
  selector: 'of-probe-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.scss']
})
export class ListComponent implements OnInit, AfterContentInit {
  probes$ = this.store.pipe(select(ListSelector.select('probes')));
  pageSize = '25';
  length = '100';

  displayedColumns = ['name', 'ip', 'os', 'cidr', 'targetCnt', 'date', 'authBy'];
  dataSource: MatTableDataSource<Probe>;
  @ViewChild(MatSort) sort: MatSort;

  constructor(
    private router: Router,
    private store: Store<ListStore.State>
  ) {
  }

  ngAfterContentInit() {
    this.probes$.subscribe(
      (probes: Probe[]) => {
        this.dataSource = new MatTableDataSource(probes);
        this.dataSource.sort = this.sort;
      },
      (error: ErrorResponse) => {

      }
    );

    this.store.select(AuthSelector.select('domain')).subscribe(
      (domain: Domain) => {
        this.store.dispatch(new ListStore.ReadAllByDomain(domain));
      },
      (error) => {

      }
    );

    // // temporary data
    // const data: Probe[] = new Array();
    // for (let i = 0; i < 100; i++) {
    //   const p: Probe = {
    //     id: i,
    //     displayName: String('displayName' + i),
    //     host: {
    //       ip: i,
    //       os: {
    //         meta: 'blahblahblah'
    //       },
    //     },
    //     cidr: String('cidr' + i),
    //     targets: [
    //       {
    //         id: i,
    //       },
    //     ],
    //     authorizeDate: new Date(),
    //     authorizeMember: {
    //       'name': String('insanity')
    //     },
    //   };
    //   data.push(p);
    // }

    // this.dataSource = new MatTableDataSource(data);
    // this.dataSource.sort = this.sort;
  }

  ngOnInit() {
  }

  handleRowClick(obj: Probe) {
    this.router.navigate(['probe', obj.id]);
  }
}
